@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,8 +15,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-import types
-
 def gcd(a, b):
     while b:
         a, b = b, a % b
@@ -30,8 +28,8 @@ class Rat(object):
     module included in Solfege.
     """
     def __init__(self, num, den=1):
-        assert type(num) == types.IntType
-        assert type(den) == types.IntType
+        assert isinstance(num, int)
+        assert isinstance(den, int)
         self.m_num = num
         self.m_den = den
     def __repr__(self):
@@ -63,7 +61,7 @@ class Rat(object):
     def __rdiv__(self, B):
         """ called when integer / Rat
         """
-        assert type(B) == types.IntType
+        assert isinstance(B, int)
         assert isinstance(self, Rat)
         a = B * self.m_den
         b = self.m_num
@@ -73,7 +71,7 @@ class Rat(object):
         """ called when integer * Rat
         """
         assert isinstance(self, Rat)
-        assert type(B) == types.IntType
+        assert isinstance(B, int)
         a = self.m_num * B
         g = gcd(a, self.m_den)
         return Rat(a/g, self.m_den/g)
