@@ -330,11 +330,17 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         gu.bButton(category_vbox, _("_Apply changes and play test sound"), self.on_apply_and_play_test_sound)
 
     def test_wav_player(self, w):
-        osutils.run_external_program(self.g_wav_player.child.get_text(),
+        try:
+            osutils.run_external_program(self.g_wav_player.child.get_text(),
                  'lesson-files/share', 'fifth-small-220.00.wav')
+        except osutils.RunExternalFailed, e:
+                self.m_app.m_ui.display_error_message(str(e))
     def test_midi_player(self, w):
-        osutils.run_external_program(self.g_midi_player.child.get_text(),
+        try:
+            osutils.run_external_program(self.g_midi_player.child.get_text(),
                         'lesson-files/share', 'fanfare.midi')
+        except osutils.RunExternalFailed, e:
+                self.m_app.m_ui.display_error_message(str(e))
     def set_gui_from_config(self):
         if self.get_string("sound/type") == "fake-synth":
             self.g_fakesynth_radio.set_active(True)
@@ -350,6 +356,7 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         else:
             if self.on_apply() == -1:
                 self.set_gui_from_config()
+                return
         self.hide()
     def on_apply_and_play_test_sound(self, *w):
         if self.on_apply() != -1:
@@ -375,6 +382,7 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         if self.g_midiplayer_radio.get_active():
             soundcard.initialise_external_midiplayer(
                   self.g_midi_player.child.get_text())
+            soundcard.synth.error_report_cb = self.m_app.m_ui.display_error_message
         elif self.g_device_radio.get_active():
             if sys.platform != 'win32' and configureoutput.HAVE_LINUX_AWE_VOICE_H and \
                 self.g_awe_checkbutton.get_active():
