@@ -235,7 +235,7 @@ class ResolveLessonIdCrashDlg(gtk.Dialog):
                 g = None
             ss = "%s %s" % (info['filename'], info['timestr'])
             if not isinstance(ss, unicode):
-                ss = ss.decode(locale.nl_langinfo(locale.CODESET), 'replace')
+                ss = ss.decode(locale.getpreferredencoding(), 'replace')
             radiobutton = gtk.RadioButton(g, ss)
             radiobutton.show()
             radiobutton.set_data('fn', info['filename'])
@@ -529,8 +529,8 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
             msg = ""
         exception_str = unicode(exception)
         if not isinstance(exception_str, unicode):
-            exception_str = exception_str.decode(locale.nl_langinfo(locale.CODESET), 'replace')
-        msg = "%s %s" %(msg, exception)
+            exception_str = exception_str.decode(locale.getpreferredencoding(), 'replace')
+        msg = "%s %s" %(msg, exception_str)
         m = gtk.MessageDialog(self, gtk.DIALOG_MODAL, gtk.MESSAGE_ERROR,
                               gtk.BUTTONS_CLOSE, msg)
         m.set_title(sys.exc_info()[0].__name__)
@@ -538,7 +538,7 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         m.destroy()
     def display_error_message(self, msg):
         if not isinstance(msg, unicode):
-            msg = msg.decode(locale.nl_langinfo(locale.CODESET), 'replace')
+            msg = msg.decode(locale.getpreferredencoding(), 'replace')
         m = gtk.MessageDialog(self, gtk.DIALOG_MODAL, gtk.MESSAGE_ERROR,
                               gtk.BUTTONS_CLOSE, None)
         m.set_markup(msg)
