@@ -161,6 +161,9 @@ class Gui(abstract.IntervalGui):
         if self.m_t.m_app.m_test_mode and self.m_t.is_test_complete():
             self.do_test_complete()
             return
+        if self.m_t.m_app.m_test_mode and self.m_t.q_status == const.QSTATUS_NO:
+            self.g_flashbar.flash(_("Click 'Start test' to begin."))
+            return
         if self.m_t.m_app.m_test_mode:
             self.g_new_interval.hide()
         if self.m_t.q_status == const.QSTATUS_NO:
