@@ -88,7 +88,16 @@ def has_gnome_canvas():
     global _has_gnome_canvas
     if _has_gnome_canvas is not None:
         return _has_gnome_canvas
-    print "Checking for gnome.canvas",
+    print "Checking for gnomecanvas...",
+    try:
+        import gnomecanvas
+        _has_gnome_canvas = True
+        print "ok"
+        return True
+    except ImportError, e:
+        print e
+        pass
+    print "Checking for gnome.canvas..."
     try:
         import gnome.canvas
         try:
