@@ -1,5 +1,5 @@
 # GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,25 +15,17 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-__exercise_data__ = {
-    'exercise_name': 'twelve-tone',
-    'menu_path': '%s/%s' % (_("_Misc exercises"), _("Sing _twelvetone")),
-    'stock-icon': 'solfege-twelve-tone',
-    'toolbar': 7,
-}
-import exercise_setup
-exercise_setup.register_exercise(__exercise_data__)
-
 import random
 import gtk
 
 import gu, const, soundcard, mpd, mpd.musicdisplayer
 import abstract, utils
+import lessonfile
 
-class Teacher(abstract.Teacher):
-    exercise_data = __exercise_data__
-    def __init__(self, exname, app, config):
-        abstract.Teacher.__init__(self, exname, app, config)
+class Teacher(abstract.LessonbasedTeacher):
+    def __init__(self, exname, app):
+        abstract.LessonbasedTeacher.__init__(self, exname, app)
+        self.lessonfileclass = lessonfile.IdByNameLessonfile
         self.m_question = None
     def new_question(self):
         self.q_status = const.QSTATUS_NEW
@@ -68,7 +60,6 @@ class Teacher(abstract.Teacher):
 class Gui(abstract.Gui):
     def __init__(self, teacher, window):
         abstract.Gui.__init__(self, teacher, window, no_notebook=1)
-        self.config_box.hide()
         self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer(utils.play_tone)
         self.g_music_displayer.clear()
         self.g_music_displayer.set_policy(gtk.POLICY_NEVER, gtk.POLICY_NEVER)
@@ -97,6 +88,7 @@ class Gui(abstract.Gui):
     def on_start_practise(self):
         self.g_new.grab_focus()
         self.g_music_displayer.clear()
+        self.handle_config_box_visibility()
     def on_end_practise(self):
         self.m_t.end_practise()
         self.g_play_first_note.set_sensitive(False)
